[−][src]Enum unicode_types::enclosed_alphanumeric_supplement::EnclosedAlphanumericSupplement
An enum to represent all characters in the EnclosedAlphanumericSupplement block.
Variants
DigitZeroFullStop\u{1f100}: '🄀'
DigitZeroComma\u{1f101}: '🄁'
DigitOneComma\u{1f102}: '🄂'
DigitTwoComma\u{1f103}: '🄃'
DigitThreeComma\u{1f104}: '🄄'
DigitFourComma\u{1f105}: '🄅'
DigitFiveComma\u{1f106}: '🄆'
DigitSixComma\u{1f107}: '🄇'
DigitSevenComma\u{1f108}: '🄈'
DigitEightComma\u{1f109}: '🄉'
DigitNineComma\u{1f10a}: '🄊'
DingbatCircledSansDashSerifDigitZero\u{1f10b}: '🄋'
DingbatNegativeCircledSansDashSerifDigitZero\u{1f10c}: '🄌'
ParenthesizedLatinCapitalLetterA\u{1f110}: '🄐'
ParenthesizedLatinCapitalLetterB\u{1f111}: '🄑'
ParenthesizedLatinCapitalLetterC\u{1f112}: '🄒'
ParenthesizedLatinCapitalLetterD\u{1f113}: '🄓'
ParenthesizedLatinCapitalLetterE\u{1f114}: '🄔'
ParenthesizedLatinCapitalLetterF\u{1f115}: '🄕'
ParenthesizedLatinCapitalLetterG\u{1f116}: '🄖'
ParenthesizedLatinCapitalLetterH\u{1f117}: '🄗'
ParenthesizedLatinCapitalLetterI\u{1f118}: '🄘'
ParenthesizedLatinCapitalLetterJ\u{1f119}: '🄙'
ParenthesizedLatinCapitalLetterK\u{1f11a}: '🄚'
ParenthesizedLatinCapitalLetterL\u{1f11b}: '🄛'
ParenthesizedLatinCapitalLetterM\u{1f11c}: '🄜'
ParenthesizedLatinCapitalLetterN\u{1f11d}: '🄝'
ParenthesizedLatinCapitalLetterO\u{1f11e}: '🄞'
ParenthesizedLatinCapitalLetterP\u{1f11f}: '🄟'
ParenthesizedLatinCapitalLetterQ\u{1f120}: '🄠'
ParenthesizedLatinCapitalLetterR\u{1f121}: '🄡'
ParenthesizedLatinCapitalLetterS\u{1f122}: '🄢'
ParenthesizedLatinCapitalLetterT\u{1f123}: '🄣'
ParenthesizedLatinCapitalLetterU\u{1f124}: '🄤'
ParenthesizedLatinCapitalLetterV\u{1f125}: '🄥'
ParenthesizedLatinCapitalLetterW\u{1f126}: '🄦'
ParenthesizedLatinCapitalLetterX\u{1f127}: '🄧'
ParenthesizedLatinCapitalLetterY\u{1f128}: '🄨'
ParenthesizedLatinCapitalLetterZ\u{1f129}: '🄩'
TortoiseShellBracketedLatinCapitalLetterS\u{1f12a}: '🄪'
CircledItalicLatinCapitalLetterC\u{1f12b}: '🄫'
CircledItalicLatinCapitalLetterR\u{1f12c}: '🄬'
CircledCd\u{1f12d}: '🄭'
CircledWz\u{1f12e}: '🄮'
CopyleftSymbol\u{1f12f}: '🄯'
SquaredLatinCapitalLetterA\u{1f130}: '🄰'
SquaredLatinCapitalLetterB\u{1f131}: '🄱'
SquaredLatinCapitalLetterC\u{1f132}: '🄲'
SquaredLatinCapitalLetterD\u{1f133}: '🄳'
SquaredLatinCapitalLetterE\u{1f134}: '🄴'
SquaredLatinCapitalLetterF\u{1f135}: '🄵'
SquaredLatinCapitalLetterG\u{1f136}: '🄶'
SquaredLatinCapitalLetterH\u{1f137}: '🄷'
SquaredLatinCapitalLetterI\u{1f138}: '🄸'
SquaredLatinCapitalLetterJ\u{1f139}: '🄹'
SquaredLatinCapitalLetterK\u{1f13a}: '🄺'
SquaredLatinCapitalLetterL\u{1f13b}: '🄻'
SquaredLatinCapitalLetterM\u{1f13c}: '🄼'
SquaredLatinCapitalLetterN\u{1f13d}: '🄽'
SquaredLatinCapitalLetterO\u{1f13e}: '🄾'
SquaredLatinCapitalLetterP\u{1f13f}: '🄿'
SquaredLatinCapitalLetterQ\u{1f140}: '🅀'
SquaredLatinCapitalLetterR\u{1f141}: '🅁'
SquaredLatinCapitalLetterS\u{1f142}: '🅂'
SquaredLatinCapitalLetterT\u{1f143}: '🅃'
SquaredLatinCapitalLetterU\u{1f144}: '🅄'
SquaredLatinCapitalLetterV\u{1f145}: '🅅'
SquaredLatinCapitalLetterW\u{1f146}: '🅆'
SquaredLatinCapitalLetterX\u{1f147}: '🅇'
SquaredLatinCapitalLetterY\u{1f148}: '🅈'
SquaredLatinCapitalLetterZ\u{1f149}: '🅉'
SquaredHv\u{1f14a}: '🅊'
SquaredMv\u{1f14b}: '🅋'
SquaredSd\u{1f14c}: '🅌'
SquaredSs\u{1f14d}: '🅍'
SquaredPpv\u{1f14e}: '🅎'
SquaredWc\u{1f14f}: '🅏'
NegativeCircledLatinCapitalLetterA\u{1f150}: '🅐'
NegativeCircledLatinCapitalLetterB\u{1f151}: '🅑'
NegativeCircledLatinCapitalLetterC\u{1f152}: '🅒'
NegativeCircledLatinCapitalLetterD\u{1f153}: '🅓'
NegativeCircledLatinCapitalLetterE\u{1f154}: '🅔'
NegativeCircledLatinCapitalLetterF\u{1f155}: '🅕'
NegativeCircledLatinCapitalLetterG\u{1f156}: '🅖'
NegativeCircledLatinCapitalLetterH\u{1f157}: '🅗'
NegativeCircledLatinCapitalLetterI\u{1f158}: '🅘'
NegativeCircledLatinCapitalLetterJ\u{1f159}: '🅙'
NegativeCircledLatinCapitalLetterK\u{1f15a}: '🅚'
NegativeCircledLatinCapitalLetterL\u{1f15b}: '🅛'
NegativeCircledLatinCapitalLetterM\u{1f15c}: '🅜'
NegativeCircledLatinCapitalLetterN\u{1f15d}: '🅝'
NegativeCircledLatinCapitalLetterO\u{1f15e}: '🅞'
NegativeCircledLatinCapitalLetterP\u{1f15f}: '🅟'
NegativeCircledLatinCapitalLetterQ\u{1f160}: '🅠'
NegativeCircledLatinCapitalLetterR\u{1f161}: '🅡'
NegativeCircledLatinCapitalLetterS\u{1f162}: '🅢'
NegativeCircledLatinCapitalLetterT\u{1f163}: '🅣'
NegativeCircledLatinCapitalLetterU\u{1f164}: '🅤'
NegativeCircledLatinCapitalLetterV\u{1f165}: '🅥'
NegativeCircledLatinCapitalLetterW\u{1f166}: '🅦'
NegativeCircledLatinCapitalLetterX\u{1f167}: '🅧'
NegativeCircledLatinCapitalLetterY\u{1f168}: '🅨'
NegativeCircledLatinCapitalLetterZ\u{1f169}: '🅩'
RaisedMcSign\u{1f16a}: '🅪'
RaisedMdSign\u{1f16b}: '🅫'
RaisedMrSign\u{1f16c}: '🅬'
NegativeSquaredLatinCapitalLetterA\u{1f170}: '🅰'
NegativeSquaredLatinCapitalLetterB\u{1f171}: '🅱'
NegativeSquaredLatinCapitalLetterC\u{1f172}: '🅲'
NegativeSquaredLatinCapitalLetterD\u{1f173}: '🅳'
NegativeSquaredLatinCapitalLetterE\u{1f174}: '🅴'
NegativeSquaredLatinCapitalLetterF\u{1f175}: '🅵'
NegativeSquaredLatinCapitalLetterG\u{1f176}: '🅶'
NegativeSquaredLatinCapitalLetterH\u{1f177}: '🅷'
NegativeSquaredLatinCapitalLetterI\u{1f178}: '🅸'
NegativeSquaredLatinCapitalLetterJ\u{1f179}: '🅹'
NegativeSquaredLatinCapitalLetterK\u{1f17a}: '🅺'
NegativeSquaredLatinCapitalLetterL\u{1f17b}: '🅻'
NegativeSquaredLatinCapitalLetterM\u{1f17c}: '🅼'
NegativeSquaredLatinCapitalLetterN\u{1f17d}: '🅽'
NegativeSquaredLatinCapitalLetterO\u{1f17e}: '🅾'
NegativeSquaredLatinCapitalLetterP\u{1f17f}: '🅿'
NegativeSquaredLatinCapitalLetterQ\u{1f180}: '🆀'
NegativeSquaredLatinCapitalLetterR\u{1f181}: '🆁'
NegativeSquaredLatinCapitalLetterS\u{1f182}: '🆂'
NegativeSquaredLatinCapitalLetterT\u{1f183}: '🆃'
NegativeSquaredLatinCapitalLetterU\u{1f184}: '🆄'
NegativeSquaredLatinCapitalLetterV\u{1f185}: '🆅'
NegativeSquaredLatinCapitalLetterW\u{1f186}: '🆆'
NegativeSquaredLatinCapitalLetterX\u{1f187}: '🆇'
NegativeSquaredLatinCapitalLetterY\u{1f188}: '🆈'
NegativeSquaredLatinCapitalLetterZ\u{1f189}: '🆉'
CrossedNegativeSquaredLatinCapitalLetterP\u{1f18a}: '🆊'
NegativeSquaredIc\u{1f18b}: '🆋'
NegativeSquaredPa\u{1f18c}: '🆌'
NegativeSquaredSa\u{1f18d}: '🆍'
NegativeSquaredAb\u{1f18e}: '🆎'
NegativeSquaredWc\u{1f18f}: '🆏'
SquareDj\u{1f190}: '🆐'
SquaredCl\u{1f191}: '🆑'
SquaredCool\u{1f192}: '🆒'
SquaredFree\u{1f193}: '🆓'
SquaredId\u{1f194}: '🆔'
SquaredNew\u{1f195}: '🆕'
SquaredNg\u{1f196}: '🆖'
SquaredOk\u{1f197}: '🆗'
SquaredSos\u{1f198}: '🆘'
SquaredUpWithExclamationMark\u{1f199}: '🆙'
SquaredVs\u{1f19a}: '🆚'
SquaredThreeD\u{1f19b}: '🆛'
SquaredSecondScreen\u{1f19c}: '🆜'
SquaredTwoK\u{1f19d}: '🆝'
SquaredFourK\u{1f19e}: '🆞'
SquaredEightK\u{1f19f}: '🆟'
SquaredFivePointOne\u{1f1a0}: '🆠'
SquaredSevenPointOne\u{1f1a1}: '🆡'
SquaredTwentyDashTwoPointTwo\u{1f1a2}: '🆢'
SquaredSixtyP\u{1f1a3}: '🆣'
SquaredOneHundredTwentyP\u{1f1a4}: '🆤'
SquaredLatinSmallLetterD\u{1f1a5}: '🆥'
SquaredHc\u{1f1a6}: '🆦'
SquaredHdr\u{1f1a7}: '🆧'
SquaredHiDashRes\u{1f1a8}: '🆨'
SquaredLossless\u{1f1a9}: '🆩'
SquaredShv\u{1f1aa}: '🆪'
SquaredUhd\u{1f1ab}: '🆫'
SquaredVod\u{1f1ac}: '🆬'
RegionalIndicatorSymbolLetterA\u{1f1e6}: '🇦'
RegionalIndicatorSymbolLetterB\u{1f1e7}: '🇧'
RegionalIndicatorSymbolLetterC\u{1f1e8}: '🇨'
RegionalIndicatorSymbolLetterD\u{1f1e9}: '🇩'
RegionalIndicatorSymbolLetterE\u{1f1ea}: '🇪'
RegionalIndicatorSymbolLetterF\u{1f1eb}: '🇫'
RegionalIndicatorSymbolLetterG\u{1f1ec}: '🇬'
RegionalIndicatorSymbolLetterH\u{1f1ed}: '🇭'
RegionalIndicatorSymbolLetterI\u{1f1ee}: '🇮'
RegionalIndicatorSymbolLetterJ\u{1f1ef}: '🇯'
RegionalIndicatorSymbolLetterK\u{1f1f0}: '🇰'
RegionalIndicatorSymbolLetterL\u{1f1f1}: '🇱'
RegionalIndicatorSymbolLetterM\u{1f1f2}: '🇲'
RegionalIndicatorSymbolLetterN\u{1f1f3}: '🇳'
RegionalIndicatorSymbolLetterO\u{1f1f4}: '🇴'
RegionalIndicatorSymbolLetterP\u{1f1f5}: '🇵'
RegionalIndicatorSymbolLetterQ\u{1f1f6}: '🇶'
RegionalIndicatorSymbolLetterR\u{1f1f7}: '🇷'
RegionalIndicatorSymbolLetterS\u{1f1f8}: '🇸'
RegionalIndicatorSymbolLetterT\u{1f1f9}: '🇹'
RegionalIndicatorSymbolLetterU\u{1f1fa}: '🇺'
RegionalIndicatorSymbolLetterV\u{1f1fb}: '🇻'
RegionalIndicatorSymbolLetterW\u{1f1fc}: '🇼'
RegionalIndicatorSymbolLetterX\u{1f1fd}: '🇽'
RegionalIndicatorSymbolLetterY\u{1f1fe}: '🇾'
Methods
impl EnclosedAlphanumericSupplement[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case